@@ -13,14 +13,16 @@ except ImportError:
 
 
 def deg_to_rad(list_deg):
+    """Convert degrees to radians"""
     list_rad = [np.radians(i) for i in list_deg]
 
     return list_rad
 
 
 def first_order_derivative(tm, var):
-    dv = scipy.interpolate.interp1d(tm, var, fill_value='extrapolate')
-    alpha = 0.01
+    """Calculate slope of first order derivative"""
+    dv = scipy.interpolate.interp1d(tm, var, fill_value='extrapolate')  # Interpolate missing values
+    alpha = 0.01  # Step to left and right
     dv_left, dv_right = ([None] * len(tm) for _ in range(2))
     i = 0
     for hour in tm:
@@ -32,9 +34,11 @@ def first_order_derivative(tm, var):
 
 
 def post_process(df, dates, stn_name, sfx, args):
+    """Calculate fsus_adjusted and quality check for fsds_adjusted"""
+    # Initialize new variables
     df['fsds_adjusted_new'] = np.float()
     df['fsus_adjusted'] = np.float()
-    thrsh = 0.1
+    thrsh = 0.1  # Threshold
     outer_idx = 0
 
     for date in dates:
@@ -42,13 +46,17 @@ def post_process(df, dates, stn_name, sfx, args):
         month = date.month
         day = date.day
 
+        # Open downloaded ceres file as dataframe
         ceres_df = xr.open_dataset(stn_name + sfx).to_dataframe()
+        # Get toa values for each day; dataframe index is date
         toa = ceres_df.loc[
              str(year)+'-'+str(month)+'-'+str(day):str(year)+'-'+str(month)+'-'+str(day)
              ][toa_incoming_shortwave_flux].values.tolist()
 
+        # Subset dataframe for each day
         df_sub = df[df.dates == date]
 
+        # Get fsds_adjusted and fsus values for that day and substitute NaN with fillvalue_float
         fsds_adjusted = df_sub['fsds_adjusted'].tolist()
         fsds_adjusted = [common.fillvalue_float if np.isnan(i) else i for i in fsds_adjusted]
 
@@ -58,8 +66,8 @@ def post_process(df, dates, stn_name, sfx, args):
         sza = df_sub['sza'].tolist()
         sza = deg_to_rad(sza)
 
+        # Calculate albedo
         fsds_alb = fsds_adjusted
-
         idx_alb = 0
         while idx_alb < len(fsds_adjusted):
             if (fsds_adjusted[idx_alb] <= 0) or (fsus_jaws[idx_alb] < 0):
@@ -69,21 +77,12 @@ def post_process(df, dates, stn_name, sfx, args):
 
         albedo = [x/y for x, y in zip(fsus_jaws, fsds_alb)]
         albedo = [abs(i) for i in albedo]
+
+        # Calculate number of hours
         hours = np.arange(len(albedo))
 
-        # Earlier used function to calculate second-order derivative, gives same result
-        '''
-        dy = np.diff(albedo, 1)
-        dx = np.diff(hours, 1)
-        yfirst = dy/dx
-        xfirst = 0.5 * (hours[:-1] + hours[1:])
-
-        dyfirst = np.diff(yfirst, 1)
-        dxfirst = np.diff(xfirst, 1)
-        ysecond = dyfirst / dxfirst
-        '''
-
         idx = 0
+        # If less than 2 values for a day, derivative not possible, continue to next day without quality check
         if len(albedo) < 2:
             while idx < len(fsds_adjusted):
                 df.at[outer_idx, 'fsds_adjusted_new'] = fsds_adjusted[idx]
@@ -91,9 +90,10 @@ def post_process(df, dates, stn_name, sfx, args):
                 outer_idx += 1
                 idx += 1
             continue
-        else:
+        else:  # Calculate second-order derivative of albedo
             alb_second_derv = first_order_derivative(hours, first_order_derivative(hours, albedo))
 
+        # Check all following conditions for each hour
         while idx < len(fsds_adjusted):
             try:
                 if np.cos(sza[idx]) <= 0:
@@ -114,6 +114,7 @@ def post_process(df, dates, stn_name, sfx, args):
                 if fsds_adjusted[idx] == 0:
                     fsus_jaws[idx] = 0
 
+                # Insert calculated values
                 df.at[outer_idx, 'fsds_adjusted_new'] = fsds_adjusted[idx]
                 df.at[outer_idx, 'fsus_adjusted'] = fsus_jaws[idx]
             except:  # Exception for list index out of range toa[idx]
@@ -129,24 +130,27 @@ def post_process(df, dates, stn_name, sfx, args):
 
 
 def main(dataset, args):
+    """Calculate adjusted downwelling and upwelling shortwave flux"""
+    # Constants
     rho = 0.8  # reflectance
     smallest_double = 2.2250738585072014e-308
-    fillvalue_double = 9.969209968386869e+36
     dtime_1970, tz = common.time_common(args.tz)
     idx_count = 0
 
     ds = dataset
-    ds = ds.drop('time_bounds')
-    df = ds.to_dataframe()
+    ds = ds.drop('time_bounds')  # Drop time_bounds dimension so that we don't have double entries of same data
+    df = ds.to_dataframe()  # Convert to dataframe
 
-    date_hour = [datetime.fromtimestamp(i, tz) for i in df.index.values]
+    date_hour = [datetime.fromtimestamp(i, tz) for i in df.index.values]  # Index is seconds since 1970
     dates = [i.date() for i in date_hour]
-    df['dates'] = dates
-    dates = sorted(set(dates), key=dates.index)
+    df['dates'] = dates  # Add dates column to dataframe
+    dates = sorted(set(dates), key=dates.index)  # Get unique dates in increasing order
 
+    # Create new columns
     df['fsds_adjusted'] = np.float()
     df['cloud_fraction'] = np.float()
 
+    # Drop 'time' as index to do proper indexing for station_name
     df.reset_index(level=['time'], inplace=True)
     stn_name = df['station_name'][0]
 
@@ -165,13 +169,14 @@ def main(dataset, args):
         toa_incoming_shortwave_flux = 'adj_atmos_sw_down_all_toa_1h'
 
     url = jaws_path + dir_ceres + stn_name + sfx
-    try:
+    try:  # Download CF_TOA file for requested station
         ceres_file = requests.get(url, allow_redirects=True)
     except requests.ConnectionError:
         print('ERROR: Unable to download CERES file from web-server, please check your internet connection \n'
               'HINT: Internet connection is needed only when performing RIGB operation')
         os._exit(1)
 
+    # Write contents of CF_TOA file to a netCDF file
     open(stn_name + sfx, 'wb').write(ceres_file.content)
 
     for date in dates:
@@ -179,20 +184,24 @@ def main(dataset, args):
         month = date.month
         day = date.day
 
+        # Open downloaded ceres file as dataframe
         ceres_df = xr.open_dataset(stn_name + sfx).to_dataframe()
+        # Get cf values for each day; dataframe index is date
         cf = ceres_df.loc[
              str(year)+'-'+str(month)+'-'+str(day):str(year)+'-'+str(month)+'-'+str(day)
              ][cloud_fraction_var].values.tolist()
 
         if args.merra:
             pass
-        else:
+        else:  # Divide cf by 100 for ceres files
             cf = [0.9999999 if i == 100 else i/100 for i in cf]
 
+        # Subset dataframe for each day
         df_sub = df[df.dates == date]
 
+        # Get fsds_jaws for that day and substitute NaN with fillvalue_float
         fsds_jaws = df_sub['fsds'].tolist()
-        fsds_jaws = [fillvalue_double if np.isnan(i) else i for i in fsds_jaws]
+        fsds_jaws = [common.fillvalue_float if np.isnan(i) else i for i in fsds_jaws]
 
         sza = df_sub['sza'].tolist()
         az = df_sub['az'].tolist()
